@@ -56,10 +56,10 @@ class CMS(HSApi):
 class COS(HSApi):
     URL = "https://api.hubapi.com/blog/v2"
 
-    def post(self, data, target_portal):
+    def post(self, data):
         url = self.URL + "/blog-posts"
 
-        params = target_portal.add_authentication({})
+        params = self.add_authentication({})
 
         r = requests.put(url, params=params, data=data)
 
@@ -68,10 +68,10 @@ class COS(HSApi):
         else:
             return False
 
-    def get_author_id(self, name, target_portal):
+    def get_author_id(self, name):
         url = self.URL + "/blog-authors"
 
-        params = target_portal.add_authentication({"full_name": name})
+        params = self.add_authentication({"full_name": name})
 
         r = requests.get(url, params=params)
 
